bcbio-gff
---------

A python library to read and write Generic Feature Format (`GFF`_).
See the `wiki documentation`_ for details on usage. The goal is to
integrate this code in `gffutils`_ and `Biopython`_.

Most of the functionality from this library has been integrated into
`gffutils <https://github.com/daler/gffutils>`_ and we recommend using that for parsing
GFF. It's an improved approach to handling GFF and well maintained by `Ryan Dale <https://github.com/daler>`_.

Installation from `bcbio-gff in pypi`_::

  pip install bcbio-gff

This code is freely available for use under the `Biopython license <https://github.com/biopython/biopython/blob/master/LICENSE>`_.

.. _GFF: http://www.sequenceontology.org/gff3.shtml
.. _wiki documentation: http://biopython.org/wiki/GFF_Parsing
.. _gffutils: https://github.com/daler/gffutils
.. _Biopython: http://biopython.org
.. _bcbio-gff in pypi: https://pypi.python.org/pypi/bcbio-gff
